#
# spec file for package postgresql-jdbc
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2000-2005, JPackage Project
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           postgresql-jdbc
Version:        42.2.25
Release:        4.4
Summary:        JDBC driver for PostgreSQL
License:        BSD-2-Clause
URL:            https://jdbc.postgresql.org/
Source0:        https://repo1.maven.org/maven2/org/postgresql/postgresql/%{version}/postgresql-%{version}-jdbc-src.tar.gz
Patch1:         CVE-2022-26520.patch
Patch2:         fix-SQL-Injection-CVE-2022-31197.patch
Patch3:         fix-createTempFile-vulnerability-CVE-2022-41946.patch
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  mvn(com.ongres.scram:client) >= 2.0
BuildArch:      noarch

%description
PostgreSQL is an advanced Object-Relational database management
system. The postgresql-jdbc package includes the .jar files needed for
Java programs to access a PostgreSQL database.

%package javadoc
Summary:        API docs for %{name}

%description javadoc
This package contains the API Documentation for %{name}.

%prep
%setup -q -n postgresql-%{version}-jdbc-src
%patch1 -p1
%patch2 -p1
%patch3 -p2

# Build parent POMs in the same Maven call.
%pom_xpath_remove "pom:plugin[pom:artifactId = 'maven-shade-plugin']"

%{mvn_file} org.postgresql:postgresql %{name}/postgresql %{name}

# For compat reasons, make Maven artifact available under older coordinates.
%{mvn_alias} org.postgresql:postgresql postgresql:postgresql

%build
%{mvn_build} -f -- -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE
%doc README.md

%files javadoc -f .mfiles-javadoc
%license LICENSE

%changelog
* Sun Jan  8 2023 Michael Calmer <mc@suse.com>
- fix createTempFile vulnerability - CVE-2022-41946 (bsc#1206921)
  * Added: fix-createTempFile-vulnerability-CVE-2022-41946.patch
* Tue Sep 27 2022 Michael Calmer <mc@suse.com>
- Address SQL Injection Vulnerability CVE-2022-31197
  (bsc#1202170)
  * Add: fix-SQL-Injection-CVE-2022-31197.patch
* Fri Jun  3 2022 Michael Calmer <mc@suse.com>
- Address arbitrary File Write Vulnerability CVE-2022-26520
  (bsc#1197356)
  * Add: CVE-2022-26520.patch
* Thu Mar  3 2022 Michael Calmer <mc@suse.com>
- Upgrade to upstream version 42.2.25
  * uses SASLprep normalization for SCRAM authentication fixing
    some issues with spaces in passwords. (bsc#1196693)
    (jsc#SLE-23993, jsc#SLE-23994)
  * https://jdbc.postgresql.org/documentation/changelog.html
* Fri Aug 28 2020 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 42.2.16
  * building with maven
- Removed patch:
  * jdbc-postgresql-9.4_p1201-remove-sspi.patch
  - not needed any more
* Tue Sep 19 2017 fstrba@suse.com
- Build with java compatibility 1.6
- Modified file:
  * build.xml
    + Detect correctly java 9
* Mon Jul  6 2015 dmacvicar@suse.de
- update to version 9.4-1200 (fate#318788)
  * https://jdbc.postgresql.org/documentation/changelog.html
- Add patch:
  * jdbc-postgresql-9.4_p1201-remove-sspi.patch
* Fri Jul 11 2014 tchvatal@suse.com
- Do not version java docdir.
* Tue Jul  8 2014 tchvatal@suse.com
- Do not depend on ant-trax.
* Fri Jun 27 2014 tchvatal@suse.com
- Fix build on SLE11
* Fri Jun 27 2014 tchvatal@suse.com
- Version bump to latest release 9.3:
  * Various fixes
  * Better integration with pgsql9.3
- Cleanup with spec-cleaner
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Thu Mar 28 2013 darin@darins.net
- Set the correct license
* Tue Mar 26 2013 darin@darins.net
- Update license
- rpmlint cleanup
* Thu Feb 21 2013 darin@darins.net
- Update to 9.2
- cleaned up .spec
- moved %%changelog to .changes
* Thu Mar  3 2011 vlado.paskov@gmail.com
- Initial package release.
